@@ -116,7 +116,7 @@ class AS3Client:
             self.handle_client_error(e)
 
 
-    def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False):
+    def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False, validate=False):
         if dst_folder[0] == '/':
             dst_folder = dst_folder[1:len(dst_folder)]
         print('DoTar {}, DoCompress {}'.format(do_tar, do_compress))
