@@ -137,7 +137,7 @@ class FTPClient():
     self.client.retrbinary('RETR ' + file_path, file.write)
     file.close()
 
-  def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False):
+  def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False, validate=False):
     dst_folder = dst_folder.strip('/')
     split_dst_file = dst_folder.split('/')
     try:
