@@ -1,4 +1,6 @@
-import os, tarfile
+import os
+import re
+import tarfile
 import pysftp
 import paramiko
 import ssh_agent_setup
@@ -35,7 +37,8 @@ class SFTPClient:
       ssh_agent_setup.setup()
 
       if not password:
-        ssh_agent_setup.addKey(private_key_path)
+        p = subprocess.run(['ssh-add', private_key_path], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+
       else:
         p = subprocess.run(['ssh-add', private_key_path], stdout=subprocess.PIPE, stderr=subprocess.PIPE,
                            input=str.encode(password))
@@ -45,6 +48,21 @@ class SFTPClient:
           print('ssh key could not be added to the agent, error code: {}'.format(p.returncode))
           raise IncorrectCredentialsException(code=403)
 
+      if p.returncode == 0:
+        output = p.stderr.decode()
+        print(f'ssh key successfully added to the agent. {output}')
+        matches = re.findall('\((.*)\)', output)
+        identity = private_key_path
+        if len(matches) != 0 and matches[0] != '':
+          print(f'regexp worked!')
+          identity = matches[0]
+        else:
+          print(f'regexp did not worked! {matches}')
+        print(f'identity extracted: {identity}')
+      else:
+        print('ssh key could not be added to the agent, error code: {}'.format(p.returncode))
+        raise IncorrectCredentialsException(code=403)
+
       ssh_add_process = subprocess.run(['ssh-add', '-L'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
       ssh_public_keys_by_file = {}
       if ssh_add_process.returncode == 0:
@@ -60,8 +78,8 @@ class SFTPClient:
           ssh_key_file_path = ssh_key_elements[2]
           ssh_public_keys_by_file[ssh_key_file_path] = ssh_public_key
 
-      print(f'ssh_public_keys_by_file -> f{ssh_public_keys_by_file}')
-      public_key_to_find = ssh_public_keys_by_file[private_key_path]
+      print(f'ssh_public_keys_by_file -> {ssh_public_keys_by_file}')
+      public_key_to_find = ssh_public_keys_by_file[identity]
 
       index_found = -1
       paramiko_ssh_keys = paramiko.Agent().get_keys()
